@@ -8,7 +8,7 @@
 # Distributed under the terms of the GPL v2
 ###############################################################################
 ###############################################################################
-# Version 1.0.4
+# Version 1.0.5
 ###############################################################################
 ###############################################################################
 # This program recursively downloads Web sites, as it goes, it changes absolute
@@ -214,7 +214,7 @@ proc TheEnd {{noEnd 0}} {
         if {($getleftState(autoDown)==1)||($getleftState(delayedDown)==1)} {
             set what yes
             if {$getleftState(autoDown)==1} {
-                mainWin::UrlListMoveBottom $getleftState(url)
+                mainWin::UrlListMoveTopBottom $getleftState(url)
             }
             if {$getleftState(delayedDown)==1} {
                 catch {wm withdraw $::Ventana::window(top)}
@@ -236,8 +236,10 @@ proc TheEnd {{noEnd 0}} {
             }
         }
     } else {
-        if {($noEnd==0)&&($getleftState(autoDown)==0)} {
+        if {$getleftState(autoDown)==0} {
             catch {wm withdraw $::Ventana::window(top)}
+        }
+        if {$noEnd==0} {
             tk_messageBox -icon info -title $labelTitles(theEnd) -type ok \
                     -message $labelMessages(theEnd)
         }
@@ -436,7 +438,7 @@ proc StartDownload {requestedUrl} {
         #set ::fin   [clock seconds]
         #puts "Time: [expr $::fin - $::start]"
         if {$downOptions(map)==0} {
-            TheEnd
+            TheEnd $getleftState(autoDown)
         } else {
             if {$getleftState(autoDown)==0} {
                 DownloadFromMap $requestedUrl
@@ -584,12 +586,10 @@ proc ReadConfig { {confFile {} } } {
             set ficherorc [file join "$dirGetleft(conf)" getleft.ini]
             set dirGetleft(lastDir) $dirGetleft(conf)
             set dirGetleft(toolDir) $dirGetleft(conf)
-            set dirGetleft(showDir) $dirGetleft(conf)
         } else {
             set ficherorc [file join "$dirGetleft(conf)" getleft.conf]
             set dirGetleft(lastDir) $env(HOME)
             set dirGetleft(toolDir) $env(HOME)
-            set dirGetleft(showDir) $env(HOME)
             set temp [file join $env(HOME) .Getleft]
             if {[file exists $temp]} {
                 set ficherorc $temp
@@ -677,9 +677,6 @@ proc ReadConfig { {confFile {} } } {
             toolDir {
                 set dirGetleft(toolDir) $line
             }
-            showDir {
-                set dirGetleft(showDir) $line
-            }
             urlQueue {
                 lappend getleftState(urlQueue) $line
             }
@@ -721,11 +718,6 @@ proc ReadConfig { {confFile {} } } {
     if {(![info exists dirGetleft(toolDir)])&&([info exists dirGetleft(lastDir)])} {
         set dirGetleft(toolDir) $dirGetleft(lastDir)
     }
-    # Idem
-    if {(![info exists dirGetleft(showDir)])&&([info exists dirGetleft(lastDir)])} {
-        set dirGetleft(showDir) [file dirname $dirGetleft(lastDir)]
-    }
-
     return 0
 }
 
@@ -797,9 +789,6 @@ proc SaveConfig {} {
     puts $fichero "\n\[toolDir\]\n"
     puts $fichero "$dirGetleft(toolDir)"
 
-    puts $fichero "\n\[showDir\]\n"
-    puts $fichero "$dirGetleft(showDir)"
-
     puts $fichero "\n\[delaySet\]\n"
     puts $fichero "$getleftState(delaySet)"
 
@@ -1449,50 +1438,13 @@ if {[file exists /etc/getlet.conf]} {
     set dirGetleft(languages) [file join "$dirGetleft(main)" Languages]
 }
 
-source [file join "$dirGetleft(scripts)" menuEntry.tcl]
-source [file join "$dirGetleft(scripts)" Ccombinado.tcl]
-source [file join "$dirGetleft(scripts)" Ventana.tcl]
-source [file join "$dirGetleft(scripts)" Dialogos.tcl]
-source [file join "$dirGetleft(scripts)" Herramientas.tcl]
-source [file join "$dirGetleft(scripts)" Ayuda.tcl]
-source [file join "$dirGetleft(scripts)" HtmlParser.tcl]
 source [file join "$dirGetleft(scripts)" mwutil.tcl]
 source [file join "$dirGetleft(scripts)" tablelistWidget.tcl]
 source [file join "$dirGetleft(scripts)" tablelistSortByColumn.tcl]
 source [file join "$dirGetleft(scripts)" balloon.tcl]
 source [file join "$dirGetleft(scripts)" mainWin.tcl]
-source [file join "$dirGetleft(scripts)" Commands.tcl]
-source [file join "$dirGetleft(scripts)" FrameLabel.tcl]
-source [file join "$dirGetleft(scripts)" Opciones.tcl]
-source [file join "$dirGetleft(scripts)" CuadroSpin.tcl]
-source [file join "$dirGetleft(scripts)" Descargar.tcl]
-source [file join "$dirGetleft(scripts)" Progreso.tcl]
-source [file join "$dirGetleft(scripts)" Cookies.tcl]
-source [file join "$dirGetleft(scripts)" ChooseLinks.tcl]
-source [file join "$dirGetleft(scripts)" getLog.tcl]
 source [file join "$dirGetleft(scripts)" delay.tcl]
-source [file join "$dirGetleft(scripts)" help.tcl]
-source [file join "$dirGetleft(scripts)" EnterUrl.tcl]
-
-ReadSupportedLang
-ReadLangFile en
-SetEncodings
-Ventana::Rizo::SetCurlVersion
-SetGetleftColours
-if {[ReadConfig]} {
-    source [file join "$dirGetleft(scripts)" getWizard.tcl]
-}
-
-Opciones::SetDefaultOptions downOptions
-
-# We are going to delete the *.gdt files that shouldn't be there any more
-set gdtFiles [glob -nocomplain [file join $dirGetleft(conf) *.gdt]]
-foreach file $gdtFiles {
-    set root [file rootname [file tail $file]]
-    if {![regexp -nocase "$root" $getleftState(urlQueue)]} {
-        file delete -force $file
-    }
-}
+source [file join "$dirGetleft(scripts)" Ventana.tcl]
 
 if {![info exists getleftState(downloading)]} {
     set getleftState(downloading)             0
@@ -1507,7 +1459,50 @@ if {![info exists getleftState(downloading)]} {
     set setIcon 1
 }
 
+SetGetleftColours
+
+ReadSupportedLang
+ReadLangFile en
+SetEncodings
+
+source [file join "$dirGetleft(scripts)" FrameLabel.tcl]
+source [file join "$dirGetleft(scripts)" Herramientas.tcl]
+
+if {[ReadConfig]} {
+    source [file join "$dirGetleft(scripts)" getWizard.tcl]
+}
+
 mainWin::MainWindow
+update
+
+source [file join "$dirGetleft(scripts)" menuEntry.tcl]
+source [file join "$dirGetleft(scripts)" Ccombinado.tcl]
+source [file join "$dirGetleft(scripts)" Dialogos.tcl]
+source [file join "$dirGetleft(scripts)" Ayuda.tcl]
+source [file join "$dirGetleft(scripts)" HtmlParser.tcl]
+source [file join "$dirGetleft(scripts)" Commands.tcl]
+source [file join "$dirGetleft(scripts)" Opciones.tcl]
+source [file join "$dirGetleft(scripts)" CuadroSpin.tcl]
+source [file join "$dirGetleft(scripts)" Descargar.tcl]
+source [file join "$dirGetleft(scripts)" Progreso.tcl]
+source [file join "$dirGetleft(scripts)" Cookies.tcl]
+source [file join "$dirGetleft(scripts)" ChooseLinks.tcl]
+source [file join "$dirGetleft(scripts)" getLog.tcl]
+source [file join "$dirGetleft(scripts)" help.tcl]
+source [file join "$dirGetleft(scripts)" EnterUrl.tcl]
+
+Ventana::Rizo::SetCurlVersion
+
+Opciones::SetDefaultOptions downOptions
+
+# We are going to delete the *.gdt files that shouldn't be there any more
+set gdtFiles [glob -nocomplain [file join $dirGetleft(conf) *.gdt]]
+foreach file $gdtFiles {
+    set root [file rootname [file tail $file]]
+    if {![regexp -nocase "$root" $getleftState(urlQueue)]} {
+        file delete -force $file
+    }
+}
 
 wm deiconify .
 
