@@ -76,8 +76,11 @@ queue           "Ustaw w kolejce"
 localDir        "Bierzcy katalog"
 notErase        "Nie czy"
 
+# NOT TRANSLATED
+top             "Top"
 up              "Do gry"
 down            "W d"
+bottom          "Bottom"
 
 # Labels for the encoding menus
 
