@@ -1,28 +1,60 @@
 ###############################################################################
 ###############################################################################
-#####                          Ccombinado.tcl
+#####                             Ccombinado.tcl
 ###############################################################################
 # This file contains a combobox type widget
 ###############################################################################
 # I don't know where this widget comes from originally, someone in college
 # 'Jess' used to give it, I think he had adapted it and I have changed it
 # further. Anyway until someone tells me differently:
-# Copyright 1999-2000 Jess, Andrs Garca. Distributed under the terms of the
-# GPL. andresgarci@retemail.es
+# Copyright 1999-2002 Jess, Andrs Garca  fandom@retemail.es
+# Distributed under the terms of the LGPL v2.
 ###############################################################################
 
+# Yes, I know this is a kludge
+
+if {![info exists ::labelMenus(cut)]} {
+    set ::labelMenus(cut)             "Cut"
+    set ::labelMenus(copy)            "Copy"
+    set ::labelMenus(paste)           "Paste"
+    set ::labelMenus(clear)           "Clear"
+    set ::labelMenus(selectAll)       "Select all"
+}
+
 namespace eval Ccombinado {
 
+# First of all we define the shape of the arrow.
+
+if {[info comm flecha] == {}} {
+    set flecha {
+        #define flecha_width 15
+        #define flecha_height 15
+        static char flecha_text_bits[] = {
+            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+            0x00, 0xf8, 0x03, 0xf0, 0x01, 0xe0, 0x00, 0x40, 0x00,
+            0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
+            0x00, 0x00, 0x00
+        }
+    }
+    image create bitmap flecha -data [set flecha]
+    unset flecha
+}
+
 ###############################################################################
 # SetEntryText
 #    Sets the selected value in the entry widget, after deleting the former
 #    one.
 ###############################################################################
 proc SetEntryText {v entry} {
+    variable cbArgs
 
     if { [set idx [$v curselection ]]!="" } {
+        $entry configure -state normal
         $entry delete 0 end
         $entry insert 0 [$v get $idx]
+        if {$cbArgs(-activeentry)==0} {
+            $entry configure -state disabled
+        }
     }
     return
 }
@@ -54,10 +86,10 @@ proc MapList {w} {
         grab release $d
         wm withdraw $d
     } else {
-        set x1 [expr [winfo rootx ${w}.fondo.boton]-\
-                [winfo reqwidth $l.cuadro]]
-        set y1 [expr [winfo rooty ${w}.fondo.boton]+\
-                [winfo height ${w}.fondo.boton]]
+        set x1 [expr {[winfo rootx ${w}.fondo.boton]-\
+                [winfo reqwidth $l.cuadro]}]
+        set y1 [expr {[winfo rooty ${w}.fondo.boton]+\
+                [winfo height ${w}.fondo.boton]}]
         wm geometry $d +$x1+$y1
         wm deiconify $d
         raise $d
@@ -75,14 +107,19 @@ proc MapList {w} {
 #    value in the entry widget, and closes the window list
 ###############################################################################
 proc Selected { w y } {
+    variable cbArgs
 
     set d ${w}_desplegable
     set l $d.listado
 
     grab release $d
 
+    $w.entry configure -state normal
     $w.entry delete 0 end
     $w.entry insert 0 [$l.cuadro get [$l.cuadro nearest $y] ]
+    if {$cbArgs(-activeentry)==0} {
+        $w.entry configure -state disabled
+    }
 
     focus $w.entry
 
@@ -139,15 +176,14 @@ proc DeleteItem {w y} {
     set index [$l.cuadro curselection]
     if {$index!=""} {
         $l.cuadro delete $index
-        $l.cuadro configure -height [expr [$l.cuadro cget -height] - 1]
-        if {$index<[expr [llength $cbArgs(items)]-1]} {
+        $l.cuadro configure -height [expr {[$l.cuadro cget -height] - 1}]
+        if {$index<[expr {[llength $cbArgs(items)]-1}]} {
             $l.cuadro selection set $index
         } else {
-            $l.cuadro selection set [expr $index -1]
+            $l.cuadro selection set [expr {$index -1}]
         }
         set cbArgs(items) [lreplace $cbArgs(items) $index $index]
     }
-
     return
 }
 
@@ -165,13 +201,12 @@ proc UnMapScrollBar { listbox scrollbar } {
     } else {
         pack $scrollbar -side right -fill y
     }
-
     return
 }
 
 ###############################################################################
 # ParseArguments
-#    Gets the optional parameters passed to ComboBox into the
+#    Gets the optional parameters passed to the ComboBox into the
 #    namespace variable 'cbArgs', the rest get the default values.
 ###############################################################################
 proc ParseArguments {parameters} {
@@ -179,9 +214,13 @@ proc ParseArguments {parameters} {
 
     upvar $parameters args
 
-    set cbArgs(-width)    50
-    set cbArgs(-default)  ""
-    set cbArgs(-erasable)  0
+    set cbArgs(-width)        50
+    set cbArgs(-default)      ""
+    set cbArgs(-erasable)      0
+    set cbArgs(-activeentry)   1
+    set cbArgs(-textvariable) ""
+    set cbArgs(-bg)           white
+    set cbArgs(-fg)           black
 
     array set cbArgs $args
 
@@ -200,45 +239,52 @@ proc ParseArguments {parameters} {
 #           -width: width of the entry, defaults to 50
 #           -erasable: '1' if the user can erase items from the listbox,
 #            defaults to '0'.
+#           -activeEntry: '1' if the user can enter new items.
+#           -textvariable: contents of the entry
+#           -bg: background color.
+#           -fg: foreground color.
+#
+# Returns
+#    The path of the combobox.
 ###############################################################################
 proc ComboBox { w items args} {
     variable cbArgs
+    global tcl_platform labelMenus
 
     frame $w -relief sunken -bd 1
-    array set cbArgs $args
+#    array set cbArgs $args
     ParseArguments args
 
     set cbArgs(items) $items
-    if {[info comm flecha] == {}} {
-        set flecha {
-            #define flecha_width 15
-            #define flecha_height 15
-                static char flecha_text_bits[] = {
-                    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
-                    0x00, 0xf8, 0x03, 0xf0, 0x01, 0xe0, 0x00, 0x40, 0x00,
-                    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
-                    0x00, 0x00, 0x00
-                }
-        }
-        image create bitmap flecha -data [set flecha]
-        unset flecha
-    }
+
 # Entry box
-    entry $w.entry -bd 1 -relief flat -width $cbArgs(-width) -bg white
+    menuEntry::menuEntry $w.entry -bd 1 -relief flat -width $cbArgs(-width) \
+            -bg $cbArgs(-bg) -fg $cbArgs(-fg)
+    catch {$w.entry configure  \
+            -disabledbackground $cbArgs(-bg)  -disabledforeground $cbArgs(-fg)}
+
     frame $w.fondo -bg gray
     $w.entry  insert 0 $cbArgs(-default)
     $w.entry  selection range 0 end	
+    if {$cbArgs(-activeentry)==1} {
+        $w.entry configure -state normal
+    } else {
+        $w.entry configure -state disable
+    }
+    if {$cbArgs(-textvariable)!=""} {
+        $w.entry configure -textvariable $cbArgs(-textvariable)
+    }
 
 # Button
     button $w.fondo.boton -image flecha -relief raised \
-        -command [namespace code "MapList $w"] -width 8 -height 10
+        -command "Ccombinado::MapList $w" -width 8 -height 10
     pack $w.entry -side left -pady 1 -padx 1 -fill x
     pack $w.fondo -side right
     pack $w.fondo.boton -side bottom -pady 1
 
 # Toplevel window with the list
     set d ${w}_desplegable
-    toplevel $d -relief raised -bd 1 -bg White
+    toplevel $d -relief raised -bd 1 -bg $cbArgs(-bg)
     wm overrideredirect $d 1
     wm transient $d
     wm withdraw $d
@@ -252,8 +298,8 @@ proc ComboBox { w items args} {
     scrollbar $l.barra -bd 1 -command "$l.cuadro yview"
 
 # Finally the listbox '$l.cuadro'
-    listbox $l.cuadro -yscroll "$l.barra set" -setgrid 1 -bg White \
-        -relief sunken -width $cbArgs(-width)
+    listbox $l.cuadro -yscroll "$l.barra set" -setgrid 1 -bg $cbArgs(-bg) \
+        -fg $cbArgs(-fg) -relief sunken -width $cbArgs(-width)
     pack $l.barra -side right -fill y
     pack $l.cuadro -side left -expand 1 -fill both
 
@@ -270,38 +316,42 @@ proc ComboBox { w items args} {
             $l.cuadro insert end $q
             if { $q==$cbArgs(-default) } {
                 set i [lsearch $cbArgs(items) $q]
-                $l.cuadro yview moveto [expr (double($i))/$numero]
-                tkListboxMotion $l.cuadro \ $i
+                $l.cuadro yview moveto [expr {(double($i))/$numero}]
+                if {[catch {tkListboxMotion $l.cuadro \ $i}]} {
+                    tk::ListboxMotion $l.cuadro \ $i
+                }
             }
         }
     }
-    bind $l.cuadro <Motion> "
-        tkListboxMotion %W \[%W index @%x,%y]
-    "
-    bind $l.cuadro <Enter> {
-        tkCancelRepeat
+    bind $l.cuadro <Motion> {
+        if {[catch {tkListboxMotion %W [%W index @%x,%y]}]} {
+            tk::ListboxMotion %W [%W index @%x,%y]
+        }
     }
-    bind $etiqueta <ButtonPress>  [namespace code {
+    bind $l.cuadro <Enter> {
+        if {[catch {tkCancelRepeat}]} {
+            tk::CancelRepeat
+        }
+    }
+    bind $etiqueta <ButtonPress>  {
         foreach q {rootx rooty width height} {
             set $q [winfo $q %W]
         }
         if {(%X < $rootx) || (%X > ($rootx+$width)) || \
                  (%Y < $rooty) || (($rooty+$height) < %Y)} {
-            UnMapList %W
+            Ccombinado::UnMapList %W
         }
-    }]
+    }
 
-    bind $etiqueta  <Return>   [namespace code "KeySelected [list $w] 1"]
-    bind $etiqueta  <KP_Enter> [namespace code "KeySelected [list $w] 1"]
-    bind $etiqueta  <Escape>   [namespace code "KeySelected [list $w] 0"]
-    bind $l.cuadro  <1>        [namespace code "Selected    [list $w] %y"]
-    bind $l.cuadro  <Delete>   [namespace code "DeleteItem  [list $w] %y"]
-    bind ${w}.entry <Down>     [namespace code "MapList ${w}"]
-    bind $l.cuadro <Configure> "
-        [namespace code "UnMapScrollBar $l.cuadro $l.barra"]
-    "
+    bind $etiqueta  <Return>    "Ccombinado::KeySelected [list $w] 1"
+    bind $etiqueta  <KP_Enter>  "Ccombinado::KeySelected [list $w] 1"
+    bind $etiqueta  <Escape>    "Ccombinado::KeySelected [list $w] 0"
+    bind $l.cuadro  <1>         "Ccombinado::Selected    [list $w] %y"
+    bind $l.cuadro  <Delete>    "Ccombinado::DeleteItem  [list $w] %y"
+    bind $w.entry   <Down>      "Ccombinado::MapList $w"
+    bind $l.cuadro  <Configure> "Ccombinado::UnMapScrollBar $l.cuadro $l.barra"
 
-    return
+    return $w
 }
 
-}
\ No newline at end of file
+}
