@@ -374,14 +374,14 @@ proc ChooseDownloads {referer linkArray} {
             -command "ChooseLinks::Chosen $linkArray {(html$)|(htm$)|(/$)} 0"]
     set lima  [label $checks.lima   -text "  $labelDialogs(images)"]
     set imaa  [button $checks.imaa  -image $mas   -width 8 -height 8 \
-            -command "ChooseLinks::Chosen $linkArray {(gif$)|(jpg$)|(jpeg$)|(bmp$)|(xbm$)|(tiff$)|(png$)} 1"]
+            -command "ChooseLinks::Chosen $linkArray {(gif$)|(jpg$)|(jpeg$)|(bmp$)|(xbm$)|(tiff?$)|(png$)} 1"]
     set imae  [button $checks.imae  -image $menos -width 8 -height 8 \
-            -command "ChooseLinks::Chosen $linkArray {(gif$)|(jpg$)|(jpeg$)|(bmp$)|(xbm$)|(tiff$)|(png$)} 0"]
+            -command "ChooseLinks::Chosen $linkArray {(gif$)|(jpg$)|(jpeg$)|(bmp$)|(xbm$)|(tiff?$)|(png$)} 0"]
     set lcom  [label $checks.lcom   -text "  $labelDialogs(archives)"]
     set coma  [button $checks.cona  -image $mas   -width 8 -height 8 \
-            -command "ChooseLinks::Chosen $linkArray {(tar$)|(gz$)|(z$)|(zip$)} 1"]
+            -command "ChooseLinks::Chosen $linkArray {(tar$)|(gz$)|(z$)|(zip$)|(tgz$)|(rpm$)|(deb$)} 1"]
     set come  [button $checks.cone  -image $menos -width 8 -height 8 \
-            -command "ChooseLinks::Chosen $linkArray {(tar$)|(gz$)|(z$)|(zip$)} 0"]
+            -command "ChooseLinks::Chosen $linkArray {(tar$)|(gz$)|(z$)|(zip$)|(tgz$)|(rpm$)|(deb$)} 0"]
     set ltodo [label $checks.ltodo  -text "  $labelDialogs(all)"]
     set todoa [button $checks.todoa -image $mas   -width 8 -height 8 \
             -command "ChooseLinks::Chosen $linkArray {.} 1"]
