@@ -14,6 +14,53 @@
 
 namespace eval Dialogos {
 
+set useWinDialog 0
+if {$tcl_platform(platform)=="windows"} {
+    if {[regexp {(8\.4b2)|(8.4$)|(8.4.0)} $tcl_patchLevel]} {
+        set useWinDialog 1
+    } else {
+        set useWinDialog 0
+    }
+}
+
+###############################################################################
+# SelectDirWindows
+#     Does the work by using a window dialog
+#
+# Parameters:
+#     initialDir: The directory in which the dialog will open itself.
+#     parent: The window over which it will appear.
+#
+# Returns:
+#     The chosen path or an empty string if the user cancels.
+#
+# Side effects:
+#     If you select a non-existing directory, it will be created for you.
+###############################################################################
+proc SelectDirWindows {initialDir parent} {
+    global labelTitles labelMessages
+
+    set chosenDir [tk_chooseDirectory -title $labelTitles(directory)         \
+            -parent $parent -initialdir $initialDir]
+
+    if {$chosenDir==""} return
+
+    if {![file exist $chosenDir]} {
+        set what [tk_messageBox -icon question \
+                -message $labelMessages(unknown) -title $labelTitles(unknown)\
+                -parent $parent -type yesno]
+        if {$what=="no"} {
+            set initialDir $chosenDir
+            while {![file exists $initialDir]} {
+                set initialDir [file dirname $initialDir]
+            }
+            return [SelectDirWindows $initialDir $parent]
+        }
+        file mkdir $chosenDir
+    }
+    return $chosenDir
+}
+
 ###############################################################################
 # SelectDirectory
 #    Opens a dialog window which allows the user to choose one directory. If
@@ -21,7 +68,7 @@ namespace eval Dialogos {
 #
 # Parameter:
 #    initialDir: directory where the dialog should open itself.
-#    parent: the parent window of the applicaction, it defaults to the main
+#    parent: the parent window of the dialog, it defaults to the main
 #    window of the app.
 #
 # Returns
@@ -29,10 +76,15 @@ namespace eval Dialogos {
 ###############################################################################
 proc SelectDirectory {{initialDir {} } {parent {.} } } {
     variable fileselect
+    variable useWinDialog
     global tcl_platform
     global dirGetleft getleftOptions labelMenus
     global env labelButtons labelTitles labelDialogs labelMessages
-    
+
+    if {$useWinDialog==1} {
+        return [SelectDirWindows $initialDir $parent]
+    }
+
     catch {destroy .fileselect}
     set t [toplevel .fileselect -bd 4]
 
