@@ -343,6 +343,8 @@ proc GetFileName {tag type} {
         } elseif {$c!=""} {
             set fileName $c
         }
+        # It seems you can write a link as //site.com/file.html
+        regsub {^//} $fileName {http://} fileName
         # Workaround for Webmasters that don't know the directory separator 
         # is a single / or feel like using the windows one \.
         regsub -all {([^:]//)|(\\)} $fileName {/} fileName
@@ -551,6 +553,9 @@ proc FilterLinks {referer linkArray} {
 
     upvar #0 $linkArray links
 
+    set baseSite $siteUrl(www)
+	regexp {(.*)(:)} $siteUrl(www)  nada baseSite
+
     for {set i 1} {[info exists links($i,url)]} {incr i} {
         set link $links($i,url)
 		set links($i,ok) 1
@@ -590,8 +595,12 @@ proc FilterLinks {referer linkArray} {
                                    log about this.
             continue
         }
-        if {[string compare [string tolower $siteUrl(www)] \
-                    [string tolower $direccion_www]]} {
+        # www.domain.com and www.domain.com:8080 will be considered the
+        # same site.
+		set linkSite $direccion_www
+		regexp {(.*)(:)} $direccion_www nada linkSite
+        if {[string compare [string tolower $baseSite] \
+                    [string tolower $linkSite]]} {
             if {$downOptions(external)==0} {
 	           set links($i,ok) 0
                 continue
@@ -602,7 +611,7 @@ proc FilterLinks {referer linkArray} {
         }
         if {($downOptions(dir)==0)&&($siteUrl(base)!="")&&($externalLink==0)} {
             if {![regexp -nocase "^$siteUrl(base)" $directory]} {
-	           set links($i,ok) 0
+				set links($i,ok) 0
                 continue
             }
         }
