@@ -15,7 +15,7 @@ namespace eval Rizo {
 
 ##############################################################################
 # SetCurlVersion
-# Getleft now only works with version 7.9.
+# Getleft now only works with version 7.9 or newer.
 ##############################################################################
 proc SetCurlVersion {} {
     global tcl_platform
@@ -26,13 +26,12 @@ proc SetCurlVersion {} {
     catch {exec curl -V} curlVersion
     set version  $curlVersion
 
-    regexp {([0-9]+\.[0-9]+)((?:\.)([0-9]+))?} $curlVersion nada \
-            curlVersion nada curlMinor
-    set curlVersion $curlVersion$curlMinor
-    if {$curlVersion<7.9} {
+    regexp {([0-9]+)(?:\.)([0-9]+)} $curlVersion nada mayor minor
+
+    if {($mayor<7)||($minor<9)} {
         tk_messageBox -title Error -type ok \
                 -message "Your 'cURL' version is too old,\n\
-                          please upgrade"
+                          please upgrade $mayor $minor"
         exit
     }
     set cookieJar [file join $::dirGetleft(conf) cookies.txt]
@@ -74,7 +73,7 @@ proc Common {type args} {
     set getleftOptions(cancelDown) 0
     set ::errorCode               ""
 
-    set newArgs [concat {-A "Mozilla/4.0 (compatible; Getleft 1.0.4)"} \
+    set newArgs [concat {-A "Mozilla/4.0 (compatible; Getleft 1.0.5)"} \
                          -b \"$cookieJar\" --connect-timeout 60 [lindex $args 0]]
 
     if {$getleftOptions(proxy)==1} {
@@ -102,7 +101,7 @@ proc Common {type args} {
         eval {set pipe [open "| $curlCmd 2>@ stdout" r]}
     }
 
-    fileevent  $pipe readable [list [namespace code Lector] $type]
+    fileevent  $pipe readable [list ::Ventana::Rizo::Lector $type]
     fconfigure $pipe -blocking 0
 
     return
@@ -234,6 +233,7 @@ proc Lector {tipo} {
 
     if {[gets $pipe line]>=0} {
         if {[string match $line ""]} return
+        if {[lsearch $line "Speed"]!=-1} return
         if {[regexp {(?:curl: \([0-9]+\) )(.*)} $line nada msg]} {
             set errorMessage $msg
             return
