@@ -309,15 +309,15 @@ proc DelayedDownloadWindow {} {
         set delayedDownloadTemp(noEnd) 1
     }
     if {[info exists Delay::delayedDownloadTemp(startTime)]} {
-        CuadroSpin::SetValue $startHour   \
+        set CuadroSpin::CuadroSpins($startHour)   \
                 [clock format $delayedDownloadTemp(startTime) -format "%H"]
-        CuadroSpin::SetValue $startMinute \
+        set CuadroSpin::CuadroSpins($startMinute) \
                 [clock format $delayedDownloadTemp(startTime) -format "%M"]
     }
     if {[info exists Delay::delayedDownloadTemp(endTime)]} {
-        CuadroSpin::SetValue $endHour     \
+        set CuadroSpin::CuadroSpins($endHour)     \
                 [clock format $delayedDownloadTemp(endTime) -format "%H"]
-        CuadroSpin::SetValue $endMinute   \
+        set CuadroSpin::CuadroSpins($endMinute)   \
                 [clock format $delayedDownloadTemp(endTime) -format "%M"]
     }
 
@@ -435,8 +435,8 @@ proc DelayedDownloadControl {done} {
     variable delayedDownloadTemp
 
     if {$done==1} {
-        set startHour   [CuadroSpin::GetValue $window(startHour)]
-        set startMinute [CuadroSpin::GetValue $window(startMinute)]
+        set startHour   $CuadroSpin::CuadroSpins($window(startHour))
+        set startMinute $CuadroSpin::CuadroSpins($window(startMinute))
 
         if {[DelayedCheckTime $startHour $startMinute]==1} {
             tk_messageBox -title $labelTitles(error) -parent $window(win) \
@@ -444,8 +444,8 @@ proc DelayedDownloadControl {done} {
             return
         }
         if {$delayedDownloadTemp(noEnd)==0} {
-            set endHour   [CuadroSpin::GetValue $window(endHour)]
-            set endMinute [CuadroSpin::GetValue $window(endMinute)]
+            set endHour   $CuadroSpin::CuadroSpins($window(endHour))
+            set endMinute $CuadroSpin::CuadroSpins($window(endMinute))
 
             if {[DelayedCheckTime $endHour $endMinute]==1} {
                 tk_messageBox -title $labelTitles(error) -parent $window(win) \
