@@ -6,7 +6,7 @@
 ## Defines the Getleft's log window.
 ###############################################################################
 ###############################################################################
-## (c) 2001 Andrs Garca Garca. fandom@retemail.es
+## (c) 2001-2002 Andrs Garca Garca. fandom@retemail.es
 ## You may distribute the contents of this file under the terms of the GPL v2
 ###############################################################################
 ###############################################################################
@@ -766,7 +766,7 @@ proc GetLogWindow {} {
         set getLog::tmpUrl   [getLog::UrlLogSelectedUrl]
         set getLog::tmpIndex [getLog::UrlLogUrlIndex $getLog::tmpUrl]
         getLog::UrlLogRemove $getLog::tmpUrl
-        $getLog::listbox selection set $getLog::tmpIndex
+        $getLog::siteLog(listbox) selection set $getLog::tmpIndex
     }
     bind $win <Escape>     "destroy $win"
 
