@@ -154,12 +154,12 @@ proc DefineTaskbarButtons {left right} {
     "]
 
     set taskbar(conf)  [button $left.conf  -image $iconNS::iconImages(conf)  \
-            -relief flat -bd 1                       \
+            -relief flat -bd 1                                               \
             -command "::mainWin::UrlListChangeOptions"]
     ::BalloonHelp::set_balloon $taskbar(conf) $labelDialogs(options)
 
     set taskbar(delay) [button $left.delay -image $iconNS::iconImages(delay) \
-            -relief flat -bd 1                       \
+            -relief flat -bd 1                                               \
             -command "::Delay::DelayedDownload"]
     if {$getleftState(delaySet)==1} {
         $taskbar(delay) configure -relief sunken
@@ -167,7 +167,7 @@ proc DefineTaskbarButtons {left right} {
     ::BalloonHelp::set_balloon $taskbar(delay) $labelDialogs(progDelay)
 
     set taskbar(log)   [button $left.log   -image $iconNS::iconImages(log)  \
-            -relief flat -bd 1                       \
+            -relief flat -bd 1                                              \
             -command "::getLog::GetLog"]
     ::BalloonHelp::set_balloon $taskbar(log) $labelDialogs(getLog)
 
@@ -206,19 +206,19 @@ proc DefineTaskbarButtons {left right} {
         "
     }
 
-    $menus(pause) add check -variable getleftOptions(pausePage) \
+    $menus(pause) add check -variable getleftOptions(pausePage)              \
             -onvalue 1 -offvalue 0 -label $labelMenus(stopPage)
-    $menus(pause) add check -variable getleftOptions(pauseFile) \
+    $menus(pause) add check -variable getleftOptions(pauseFile)              \
             -onvalue 1 -offvalue 0 -label $labelMenus(stopFile)
 
-    $menus(stop) add check -variable getleftOptions(stopPage)  \
-            -onvalue 1 -offvalue 0 -label $labelMenus(stopPage)\
+    $menus(stop) add check -variable getleftOptions(stopPage)                \
+            -onvalue 1 -offvalue 0 -label $labelMenus(stopPage)              \
             -command {
                 if {$getleftState(autoDown)==1}    mainWin::SetAutoDownload
                 if {$getleftState(delayedDown)==1} Delay::DelayedCancelDelay
             }
-    $menus(stop) add check -variable getleftOptions(stopFile)  \
-            -onvalue 1 -offvalue 0 -label $labelMenus(stopFile)\
+    $menus(stop) add check -variable getleftOptions(stopFile)                \
+            -onvalue 1 -offvalue 0 -label $labelMenus(stopFile)              \
             -command {
                 if {$getleftState(autoDown)==1}    mainWin::SetAutoDownload
                 if {$getleftState(delayedDown)==1} Delay::DelayedCancelDelay
@@ -354,10 +354,10 @@ proc UrlListDeleteEntry {url} {
 
     set index [lsearch $getleftState(urlQueue) $url]
     if {$index==-1} return
-    set getleftState(urlQueue) \
+    set getleftState(urlQueue)                                             \
             [lreplace $getleftState(urlQueue) $index $index]
 
-    getLog::UrlLogEnter $url $urlsToDownload($url,dir)      \
+    getLog::UrlLogEnter $url $urlsToDownload($url,dir)                     \
         $urlsToDownload($url,options)
 
     catch {unset urlsToDownload($url)}
@@ -400,8 +400,8 @@ proc UrlListMoveEntry {url tableIndex how} {
     }
     $listbox delete $tableIndex
     set tableIndex [expr $tableIndex + $how]
-    $listbox insert $tableIndex [list         \
-            $url $urlsToDownload($url,resume) \
+    $listbox insert $tableIndex [list                            \
+            $url $urlsToDownload($url,resume)                    \
             [file nativename $urlsToDownload($url,dir)]]
     set getleftState(urlQueue) [lreplace $getleftState(urlQueue) \
             $urlIndex $urlIndex]
@@ -415,27 +415,37 @@ proc UrlListMoveEntry {url tableIndex how} {
 }
 
 ################################################################################
-# UrlListMoveBottom
-#   Moves one of the urls to the button of the list.
+# UrlListMoveTopBottom
+#   Moves one of the urls to the top or the bottom of the list.
 #
 # Parameters
 #   url: The url of the entry to delete.
+#   where: Either 'top' or 'bottom', defaults to 'bottom'
 ################################################################################
-proc UrlListMoveBottom {url} {
+proc UrlListMoveTopBottom {url {where bottom}} {
     variable listbox
     global getleftState urlsToDownload
 
     set urlIndex [lsearch $getleftState(urlQueue) $url]
     set tableIndex [UrlListUrlIndex $url]
 
+    if {$where=="bottom"} {
+        set where end
+    } else {
+        set where 0
+    }
+
     set rowLimit [expr [$listbox size] - 1]
-    if {$rowLimit==$tableIndex} {
+    if {($rowLimit==$tableIndex)&&($where=="end")} {
+        return
+    }
+    if {($tableIndex==0)&&($where==0)} {
         return
     }
 
     $listbox delete $tableIndex
-    $listbox insert end [list                 \
-            $url $urlsToDownload($url,resume) \
+    $listbox insert $where [list                                 \
+            $url $urlsToDownload($url,resume)                    \
             [file nativename $urlsToDownload($url,dir)]]
 
     set getleftState(urlQueue) [lreplace $getleftState(urlQueue) \
@@ -589,10 +599,14 @@ proc UrlListRightClick {win x y X Y} {
                 clipboard append [mainWin::UrlListSelectedUrl]
             "
     $menus(rightClick) entryconfigure 6             \
-            -command "mainWin::UrlListMoveEntry [mainWin::UrlListSelectedUrl] $index -1"
+            -command "mainWin::UrlListMoveTopBottom [mainWin::UrlListSelectedUrl] top"
     $menus(rightClick) entryconfigure 7             \
+            -command "mainWin::UrlListMoveEntry [mainWin::UrlListSelectedUrl] $index -1"
+    $menus(rightClick) entryconfigure 8             \
             -command "mainWin::UrlListMoveEntry [mainWin::UrlListSelectedUrl] $index  1"
     $menus(rightClick) entryconfigure 9             \
+            -command "mainWin::UrlListMoveTopBottom [mainWin::UrlListSelectedUrl] bottom"
+    $menus(rightClick) entryconfigure 11            \
             -command "mainWin::UrlListDeleteEntry [mainWin::UrlListSelectedUrl]"
 
     if {$getleftState(downloading)==0} {
@@ -747,7 +761,7 @@ proc MenusLabels {{labFile ""}} {
             -underline $indexMenus(restoreOrig)
     $menus(3)   entryconfigure 2 -label $labelMenus(configureProxy) \
             -underline $indexMenus(configureProxy)
-    $menus(3)   entryconfigure 3 -label $labelMenus(getLog)       \
+    $menus(3)   entryconfigure 3 -label $labelMenus(getLog)         \
             -underline $indexMenus(getLog)
     $menus(3)   entryconfigure 4 -label $labelMenus(languages)      \
             -underline $indexMenus(languages)
@@ -978,7 +992,7 @@ proc MainWindow {} {
     variable taskbar
     variable scrollBars
 
-    wm title . "Getleft v1.0.4"
+    wm title . "Getleft v1.0.5"
     wm minsize . 300 165
 
     if {[winfo exists .menus]} {
@@ -997,18 +1011,18 @@ proc MainWindow {} {
     set rightIconFrame [frame $iconFrame.right]
     DefineTaskbarButtons $leftIconFrame $rightIconFrame
 
-    set scrollBars(y) [scrollbar $listFrame.scrolly -orient vertical   \
-            -command [list $listFrame.listbox yview]]
-    set scrollBars(x) [scrollbar $listFrame.scrollx -orient horizontal \
-            -command [list $listFrame.listbox xview]]
+    set scrollBars(y) [scrollbar $listFrame.scrolly -orient vertical       \
+            -command  [list $listFrame.listbox yview]]
+    set scrollBars(x) [scrollbar $listFrame.scrollx -orient horizontal     \
+            -command  [list $listFrame.listbox xview]]
 
-    set listbox [::tablelist::tablelist $listFrame.listbox      \
-            -bd 0 -height 10 -width 90 -stretch 3               \
-            -fg $getleftOptions(fg) -bg $getleftOptions(bg)     \
-            -columns [list 44 $labelDialogs(url)      left      \
-                            0 $labelDialogs(resumed)  center    \
-                           30 $labelDialogs(localDir) left]     \
-            -xscrollcommand "$scrollBars(x) set"                \
+    set listbox [::tablelist::tablelist $listFrame.listbox                 \
+            -bd 0 -height 10 -width 90 -stretch 3                          \
+            -fg $getleftOptions(fg) -bg $getleftOptions(bg)                \
+            -columns [list 44 $labelDialogs(url)      left                 \
+                            0 $labelDialogs(resumed)  center               \
+                           30 $labelDialogs(localDir) left]                \
+            -xscrollcommand "$scrollBars(x) set"                           \
             -yscrollcommand "$scrollBars(y) set"]
 
     set intCtrFrame [frame $ctrFrame.int -bd 2 -relief sunken]
@@ -1031,7 +1045,7 @@ proc MainWindow {} {
     grid $listFrame -sticky news -pady 2
     grid $scrollBars(y) -in $listFrame -row 0 -column 1 -sticky ns
     grid $scrollBars(x) -in $listFrame -row 1 -column 0 -sticky ew
-    grid $listbox       -in $listFrame -row 0 -column 0 -sticky news \
+    grid $listbox       -in $listFrame -row 0 -column 0 -sticky news     \
             -padx 0 -pady 0
 
     grid rowconfigure    .          0 -weight 1
@@ -1101,8 +1115,10 @@ proc MainWindow {} {
     $menus(rightClick) add separator
     $menus(rightClick) add command -label $labelDialogs(copyLink)
     $menus(rightClick) add separator
+    $menus(rightClick) add command -label $labelMenus(top)
     $menus(rightClick) add command -label $labelMenus(up)
     $menus(rightClick) add command -label $labelMenus(down)
+    $menus(rightClick) add command -label $labelMenus(bottom)
     $menus(rightClick) add separator
     $menus(rightClick) add command -label $labelMenus(delete)
  
